pyrings
=======

Python package to handle coherent vortex (rings and eddies) in the ocean.

A set of functions and classes to deal with rings/eddies identified by the velocity field. It does not require any specific data distribution, i.e. works fine with irregularly distributed data, like ship tracks, or even with hybrid mixed dataset composed from different instruments.

The center is estimated and the data is re-estructured to a natural coordinate system.
